package com.example.dtf.db

import android.content.Context
import androidx.room.*
import com.example.dtf.models.Category
import com.example.dtf.models.Comment
import com.example.dtf.models.Post
import com.example.dtf.models.User
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import androidx.sqlite.db.SupportSQLiteDatabase
import com.example.dtf.dao.*
import java.util.Date

@Database(
    entities = [
        User::class,
        Category::class,
        Post::class,
        Comment::class
    ],
    version = 1,
    exportSchema = false
)
@TypeConverters(Converter::class)
abstract class AppDatabase : RoomDatabase() {
    abstract fun userDao() : UserDao
    abstract fun categoryDao() : CategoryDao
    abstract fun commentDao() : CommentDao
    abstract fun postDao() : PostDao

    companion object {
        private const val DB_NAME: String = "news-db"

        @Volatile
        private var INSTANCE: AppDatabase? = null

        private suspend fun populateDatabase() {
            INSTANCE?.let { database ->
                val userDao = database.userDao()

                userDao.insert(User(1, "Sheriff", "123456", true))
                userDao.insert(User(2, "Человек", "123456", true))

                val categoryDao = database.categoryDao()

                categoryDao.insert(Category(1, "Игры"))
                categoryDao.insert(Category(2, "Кино"))
                categoryDao.insert(Category(3, "Аниме"))

                val postDao = database.postDao()

                postDao.insert(
                    Post(
                        1,
                        "Что не так с half-life 2",
                        "Да всё не так",
                        Date(2023, 10, 22),
                        1,
                        1
                    )
                )
                postDao.insert(
                    Post(
                        2,
                        "Я действительно ненавижу фильм про титаник",
                        "Пруфов не будет",
                        Date(2023, 9, 22),
                        1,
                        2
                    )
                )
                postDao.insert(
                    Post(
                        3,
                        "\"Госпожа Кагуя\" это переоценённый тайтл",
                        "Я, конечно, не смотрел, но мне так кажется. А всё потому, что там происходит такое, что даже Аристотелю не снилось. А может даже Платону. Об этом можно рассуждать тысячи лет, но я смогу уложиться всего в пару слов. И первое слово - этот тайтл полное днище. Ладно, не слово",
                        Date(2023, 9, 22),
                        1,
                        3
                    )
                )
                postDao.insert(
                    Post(
                        4,
                        "\"Восхождение в тени\" это переоценённый тайтл",
                        "Я, конечно, не смотрел, но мне так кажется. А всё потому, что там происходит такое, что даже Аристотелю не снилось. А может даже Платону. Об этом можно рассуждать тысячи лет, но я смогу уложиться всего в пару слов. И первое слово - этот тайтл полное днище. Ладно, не слово",
                        Date(2023, 9, 22),
                        1,
                        3
                    )
                )
                postDao.insert(
                    Post(
                        5,
                        "\"Наруто\" это переоценённый тайтл",
                        "Я, конечно, не смотрел, но мне так кажется. А всё потому, что там происходит такое, что даже Аристотелю не снилось. А может даже Платону. Об этом можно рассуждать тысячи лет, но я смогу уложиться всего в пару слов. И первое слово - этот тайтл полное днище. Ладно, не слово",
                        Date(2023, 9, 22),
                        1,
                        3
                    )
                )
                postDao.insert(
                    Post(
                        6,
                        "\"Блич\" это переоценённый тайтл",
                        "Я, конечно, не смотрел, но мне так кажется. А всё потому, что там происходит такое, что даже Аристотелю не снилось. А может даже Платону. Об этом можно рассуждать тысячи лет, но я смогу уложиться всего в пару слов. И первое слово - этот тайтл полное днище. Ладно, не слово",
                        Date(2023, 9, 22),
                        1,
                        3
                    )
                )

                val commentDao = database.commentDao()

                commentDao.insert(Comment(1, 2, 1, "Пост бред. Начнём с того, что вот эта твоя манера речи клоунская...", Date(2023, 10, 20)))
                commentDao.insert(Comment(2, 1, 1, "Да какой бред, чел, я всё по факту сказал", Date(2023, 10, 20)))
                commentDao.insert(Comment(3, 2, 3,"Автора на увольнение", Date(2023, 9, 20)))
                commentDao.insert(Comment(4, 2, 4,"Автора на увольнение дважды", Date(2023, 9, 20)))
                commentDao.insert(Comment(5, 2, 5,"Автора на увольнение трижды", Date(2023, 9, 20)))
                commentDao.insert(Comment(6, 2, 6,"Автора на увольнение четырежды", Date(2023, 9, 20)))
            }
        }

        fun getInstance(appContext: Context): AppDatabase {
            return INSTANCE ?: synchronized(this) {
                Room.databaseBuilder(
                    appContext,
                    AppDatabase::class.java,
                    DB_NAME
                )
                    .addCallback(object : Callback() {
                        override fun onCreate(db: SupportSQLiteDatabase) {
                            super.onCreate(db)
                            CoroutineScope(Dispatchers.IO).launch {
                                populateDatabase()
                            }
                        }
                    })
                    .build()
                    .also { INSTANCE = it }
            }
        }
    }

}