package com.example.dtf.screens

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.*
import androidx.compose.runtime.*
import androidx.compose.ui.*
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.ui.unit.*
import com.example.dtf.db.AppDatabase
import com.example.dtf.widgets.MyTextField
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext

@Composable
fun EditPostScreen(postId: Int) {
    val context = LocalContext.current

    val title = remember { mutableStateOf(TextFieldValue("")) }
    val content = remember { mutableStateOf(TextFieldValue("")) }

    LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            AppDatabase.getInstance(context).postDao().getById(postId).collect { data ->
                title.value = TextFieldValue(data.post.title)
                content.value = TextFieldValue(data.post.content)
            }
        }
    }

    Column(
        modifier = Modifier.verticalScroll(rememberScrollState()),
        verticalArrangement = Arrangement.spacedBy(10.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        MyTextField(
            value = title,
            "Заголовок",
            onChanged = {title.value = it},
            modifier = Modifier.fillMaxWidth().padding(15.dp, 10.dp, 15.dp, 0.dp),
            backgroundColor = Color(0xFFFEFEFE)
        )
        MyTextField(
            value = content,
            "Содержимое",
            onChanged = {content.value = it},
            modifier = Modifier.fillMaxWidth().heightIn(min = 500.dp).padding(horizontal = 15.dp),
            backgroundColor = Color(0xFFFEFEFE),
            false
        )
        Button(
            {

            },
            colors = ButtonDefaults.buttonColors(Color(0xFF388DF2)),
            border = BorderStroke(1.dp, Color(0xFF0085FF)),
            shape = RoundedCornerShape(15.dp),
            modifier = Modifier.fillMaxWidth(0.5f)
        ) {
            Text(
                text = "Сохранить",
                style = TextStyle(
                    fontSize = 24.sp,
                    fontWeight = FontWeight(400),
                    color = Color(0xFFFFFFFF),
                )
            )
        }
        Spacer(modifier = Modifier.height(70.dp))
    }
}