package com.example.dtf.screens

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.*
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.AddCircle
import androidx.compose.material.icons.filled.ThumbUp
import androidx.compose.runtime.Composable
import androidx.compose.runtime.*
import androidx.compose.ui.*
import androidx.compose.ui.draw.*
import androidx.compose.ui.graphics.*
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.*
import androidx.navigation.NavHostController
import com.example.dtf.db.AppDatabase
import com.example.dtf.models.Comment
import com.example.dtf.models.Post
import com.example.dtf.models.PostWithComments
import com.example.dtf.models.User
import com.example.dtf.utils.ScreenPaths
import com.example.dtf.widgets.MyTextField
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import java.util.Date

@Composable
fun PostScreen(postId: Int, navController: NavHostController) {
    val post = remember { mutableStateOf(PostWithComments(Post(null, "", "", Date(), -1, -1), listOf())) }

    val user = remember { mutableStateOf(User(-1, "", "", false)) }
    val context = LocalContext.current

    LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            user.value = AppDatabase.getInstance(context).userDao().getById(1)
            AppDatabase.getInstance(context).postDao().getById(postId).collect {data ->
                post.value = data
            }
        }
    }

    val content = remember { mutableStateOf(TextFieldValue("")) }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(Color.White)
            .verticalScroll(rememberScrollState()),
        verticalArrangement = Arrangement.spacedBy(5.dp),
        horizontalAlignment = Alignment.Start
    ) {
        Text(
            modifier = Modifier.padding(10.dp),
            text = post.value.post.title,
            fontSize = 26.sp
        )
        Text(
            modifier = Modifier.fillMaxHeight().padding(10.dp, 0.dp, 10.dp, 0.dp),
            text = post.value.post.content,
            fontSize = 20.sp
        )
        Row(
            modifier = Modifier.fillMaxWidth().padding(10.dp),
            verticalAlignment = Alignment.Bottom,
            horizontalArrangement = Arrangement.SpaceBetween
        ) {
            Text(
                text = "day.month.year".replace(
                    "day",
                    post.value.post.date.day.toString()
                ).replace(
                    "month",
                    post.value.post.date.month.toString()
                ).replace(
                    "year",
                    post.value.post.date.year.toString()
                ),
                fontSize = 14.sp,
                color = Color(0xFFCECCCC)
            )
            if (user.value.isModerator) {
                Text(
                    modifier = Modifier.clickable {
                        navController.navigate(ScreenPaths.EditPost.route.replace("{post}", postId.toString()))
                    },
                    text = "Изменить",
                    fontSize = 18.sp,
                    color = Color(0xFFAFAFAF)
                )
            }
            Row (
                modifier = Modifier,
                horizontalArrangement = Arrangement.End
            ) {
                Text(
                    text = "0",
                    fontSize = 16.sp,
                    color = Color.Green
                )
                Icon(
                    modifier = Modifier.padding(start = 8.dp),
                    imageVector = Icons.Default.ThumbUp,
                    contentDescription = null
                )
            }
        }
        Divider()
        Text(
            modifier = Modifier.fillMaxWidth().padding(0.dp, 0.dp, 0.dp, 10.dp),
            text = "Комментарии",
            fontSize = 22.sp,
            textAlign = TextAlign.Center
        )
        Row(
            modifier = Modifier.fillMaxSize().padding(horizontal = 15.dp),
            verticalAlignment = Alignment.CenterVertically
        ) {
            MyTextField(
                value = content,
                placeholder = "Комментарий",
                onChanged = {content.value = it},
                modifier = Modifier.fillMaxWidth(0.9f),
                backgroundColor = Color.White
            )
            IconButton(
                modifier = Modifier.fillMaxWidth().scale(1.5f),
                onClick = {},
            ) {
                Icon(
                    imageVector = Icons.Default.AddCircle,
                    contentDescription = null
                )
            }
        }
        post.value.comments.reversed().forEach() {comment ->
            Comment(comment)
        }
        Spacer(modifier = Modifier.height(60.dp))
    }
}

@Composable
private fun Comment(comment: Comment) {
    val user = remember { mutableStateOf(User(-1, "", "", false)) }
    val context = LocalContext.current

    LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            user.value = AppDatabase.getInstance(context).userDao().getById(comment.userId)
        }
    }

    Column(
        modifier = Modifier
                   .fillMaxWidth()
                   .padding(horizontal = 15.dp, vertical = 5.dp)
                   .border(width = 1.dp, color = Color(0xFFADADAD), shape = RoundedCornerShape(size = 10.dp))
                   .background(color = Color(0xFFFFFFFF), shape = RoundedCornerShape(size = 10.dp))
    ) {
        Row(
            modifier = Modifier.fillMaxWidth().padding(10.dp),
            verticalAlignment = Alignment.Top,
            horizontalArrangement = Arrangement.SpaceBetween
        ) {
            Text(
                text = user.value.username,
                fontSize = 20.sp
            )
            Text(
                text = "day.month.year".replace(
                    "day",
                    comment.date.day.toString()
                ).replace(
                    "month",
                    comment.date.month.toString()
                ).replace(
                    "year",
                    comment.date.year.toString()
                ),
                fontSize = 14.sp,
                color = Color(0xFFCECCCC)
            )
        }
        Text(
            modifier = Modifier.padding(start = 10.dp, bottom = 5.dp),
            text = comment.content,
            fontSize = 16.sp
        )
    }
}