package com.example.dtf.screens

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.*
import androidx.compose.material.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ThumbUp
import androidx.compose.runtime.Composable
import androidx.compose.runtime.*
import androidx.compose.ui.*
import androidx.compose.ui.draw.*
import androidx.compose.ui.geometry.*
import androidx.compose.ui.graphics.*
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.*
import androidx.navigation.NavHostController
import com.example.dtf.db.AppDatabase
import com.example.dtf.models.Category
import com.example.dtf.models.CategoryWithPosts
import com.example.dtf.utils.ScreenPaths
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

@Composable
fun PostsScreen(navController: NavHostController) {
    val currentCategory = remember { mutableStateOf("") }
    val categories = remember { mutableListOf<Category> () }
    val categoryWithPosts = remember { mutableStateOf(CategoryWithPosts(Category(-1, ""), listOf()))}
    val context = LocalContext.current
    val scope = rememberCoroutineScope()

    LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            AppDatabase.getInstance(context).categoryDao().getAll().collect {data ->
                currentCategory.value = data.first().name
                categories.clear()
                categories.addAll(data)
                AppDatabase.getInstance(context).categoryDao().getByName(currentCategory.value).collect {data ->
                    categoryWithPosts.value = data
                }
            }
        }
    }

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.spacedBy(10.dp)
    ) {
        Row(
            modifier = Modifier
                       .fillMaxWidth()
                       .fillMaxHeight(0.1f)
                       .horizontalScroll(
                            rememberScrollState()
                       )
                       .background(Color.White),
            horizontalArrangement = Arrangement.spacedBy(25.dp),
            verticalAlignment = Alignment.CenterVertically
        ) {
            Categories(scope, categoryWithPosts, currentCategory, categories)
        }
        Row(
            modifier = Modifier.fillMaxSize()
        ) {
            Column(
                modifier = Modifier.fillMaxSize().verticalScroll(rememberScrollState()),
                verticalArrangement = Arrangement.spacedBy(10.dp)
            ) {
                if (currentCategory.value.isNotEmpty()) {
                    PostsByCategory(navController, categoryWithPosts)
                }
                Spacer(modifier = Modifier.height(60.dp))
            }
        }
    }
}

@Composable
private fun Categories(scope: CoroutineScope, categoryWithPosts: MutableState<CategoryWithPosts>, categoryState: MutableState<String>, categories: MutableList<Category>) {
    val context = LocalContext.current

    Spacer(modifier = Modifier.width(5.dp))
    categories.forEach {category ->
        Text(
            modifier = Modifier
                .clickable {
                    categoryState.value = category.name
                    scope.launch {
                        AppDatabase.getInstance(context).categoryDao().getByName(categoryState.value).collect { data ->
                            categoryWithPosts.value = data
                        }
                    }
                }
                .drawBehind {
                    if (category.name == categoryState.value) {
                        val strokeWidthPx = 2.dp.toPx()
                        val verticalOffset = size.height + 2.sp.toPx()
                        drawLine(
                            color = Color(0xFF319CFF),
                            strokeWidth = strokeWidthPx,
                            start = Offset(0f, verticalOffset),
                            end = Offset(size.width, verticalOffset)
                        )
                    }
                },
            text = category.name,
            fontSize = 22.sp
        )
    }
}

@Composable
private fun PostsByCategory(navController: NavHostController, categoryWithPosts: MutableState<CategoryWithPosts>) {
    categoryWithPosts.value.posts.forEach { post ->
        Column(
            modifier = Modifier
                       .fillMaxHeight(0.3f)
                       .heightIn(max = 250.dp)
                       .fillMaxWidth()
                       .background(Color.White)
                       .clickable {
                           navController.navigate(ScreenPaths.Post.route.replace("{post}", post.id.toString()))
                       },
            verticalArrangement = Arrangement.spacedBy(5.dp),
            horizontalAlignment = Alignment.Start
        ) {
            Text(
                modifier = Modifier.padding(10.dp),
                text = post.title,
                fontSize = 26.sp
            )
            Text(
                modifier = Modifier.fillMaxHeight(0.6f).padding(10.dp, 0.dp, 10.dp, 0.dp),
                text = post.content,
                fontSize = 20.sp,
                overflow = TextOverflow.Ellipsis
            )
            Row(
                modifier = Modifier.fillMaxWidth().padding(10.dp),
                verticalAlignment = Alignment.Bottom,
                horizontalArrangement = Arrangement.SpaceBetween
            ) {
                Text(
                    text = "day.month.year".replace(
                        "day",
                        post.date.day.toString()
                    ).replace(
                        "month",
                        post.date.month.toString()
                    ).replace(
                        "year",
                        post.date.year.toString()
                    ),
                    fontSize = 14.sp,
                    color = Color(0xFFCECCCC)
                )
                Row (
                    modifier = Modifier.fillMaxWidth(),
                    horizontalArrangement = Arrangement.End
                ) {
                    Text(
                        text = "0",
                        fontSize = 16.sp,
                        color = Color.Green
                    )
                    Icon(
                        modifier = Modifier.padding(start = 8.dp),
                        imageVector = Icons.Default.ThumbUp,
                        contentDescription = null
                    )
                }
            }
        }
    }
}